@@ -115,13 +115,7 @@ public class EmailNotificationsConsumer extends Thread {
 		else { //use localhost (probaly postfix instance)
 			session = Session.getDefaultInstance(props);
 		}
-		//should fix javax.activation.UnsupportedDataTypeException: no object DCH for MIME type multipart/alternative; 
-		MailcapCommandMap mc = (MailcapCommandMap) CommandMap.getDefaultCommandMap(); 
-		mc.addMailcap("text/html;; x-java-content-handler=com.sun.mail.handlers.text_html"); 
-		mc.addMailcap("text/xml;; x-java-content-handler=com.sun.mail.handlers.text_xml"); 
-		mc.addMailcap("text/plain;; x-java-content-handler=com.sun.mail.handlers.text_plain"); 
-		mc.addMailcap("multipart/*;; x-java-content-handler=com.sun.mail.handlers.multipart_mixed"); 
-		mc.addMailcap("message/rfc822;; x-java-content- handler=com.sun.mail.handlers.message_rfc822");
+	
 		session.setDebug(true);
 		
 		for (;;) {
@@ -134,6 +128,8 @@ public class EmailNotificationsConsumer extends Thread {
 			if (EmailPlugin.BUFFER_EMAILS != null && EmailPlugin.BUFFER_EMAILS.size() > 0) {
 				_log.debug("Emails Buffer not empty, sending emails ");
 				Transport t = null;
+				//should fix javax.activation.UnsupportedDataTypeException: no object DCH for MIME type multipart/alternative; 
+				Thread.currentThread().setContextClassLoader( getClass().getClassLoader() );
 				try {
 					t = session.getTransport("smtp");
 					t.connect();
